@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "easy-jekyll" "2.7.30"
+(define-package "easy-jekyll" "20250830.1006"
   "Major mode managing jekyll blogs."
   '((emacs   "25.1")
     (request "0.3.0"))
